==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ReceptaLekKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class ReceptaLekKey extends GenericDPSObject {
    /**
     * RECEPTA_LEK.RECEPTA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long receptaId;

    /**
     * RECEPTA_LEK.LEK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long lekId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RECEPTA_LEK.RECEPTA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getReceptaId() {
        return receptaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:41
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * RECEPTA_LEK.RECEPTA_ID
     *
     * @param receptaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setReceptaId(Long receptaId) {
        this.receptaId = receptaId;
    }

    /**
     * @return RECEPTA_LEK.LEK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getLekId() {
        return lekId;
    }

    /**
     * RECEPTA_LEK.LEK_ID
     *
     * @param lekId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLekId(Long lekId) {
        this.lekId = lekId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ReceptaLekKey other = (ReceptaLekKey) that;
        return (this.getReceptaId() == null ? other.getReceptaId() == null : this.getReceptaId().equals(other.getReceptaId()))
            && (this.getLekId() == null ? other.getLekId() == null : this.getLekId().equals(other.getLekId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getReceptaId() == null) ? 0 : getReceptaId().hashCode());
        result = prime * result + ((getLekId() == null) ? 0 : getLekId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", receptaId=").append(receptaId);
        sb.append(", lekId=").append(lekId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ReceptaLekKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class ReceptaLekKey extends GenericDPSObject {
    /**
     * RECEPTA_LEK.RECEPTA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long receptaId;

    /**
     * RECEPTA_LEK.LEK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long lekId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RECEPTA_LEK.RECEPTA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getReceptaId() {
        return receptaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * RECEPTA_LEK.RECEPTA_ID
     *
     * @param receptaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setReceptaId(Long receptaId) {
        this.receptaId = receptaId;
    }

    /**
     * @return RECEPTA_LEK.LEK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getLekId() {
        return lekId;
    }

    /**
     * RECEPTA_LEK.LEK_ID
     *
     * @param lekId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLekId(Long lekId) {
        this.lekId = lekId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ReceptaLekKey other = (ReceptaLekKey) that;
        return (this.getReceptaId() == null ? other.getReceptaId() == null : this.getReceptaId().equals(other.getReceptaId()))
            && (this.getLekId() == null ? other.getLekId() == null : this.getLekId().equals(other.getLekId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getReceptaId() == null) ? 0 : getReceptaId().hashCode());
        result = prime * result + ((getLekId() == null) ? 0 : getLekId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", receptaId=").append(receptaId);
        sb.append(", lekId=").append(lekId);
        sb.append("]");
        return sb.toString();
    }
}
